Learn R Programming

Rnightly (version 0.1.0)

use_nightly: Enables the nightly javascript library

Description

The function activates the capabilities of the nightly javascript library. The user can put it anywhere within the UI.

Usage

use_nightly()

Arguments

Value

called for the side effect of activating the scrollrevealjs library

Examples

Run this code
# NOT RUN {
# Put the function within your shiny ui

use_nightly()



# }

Run the code above in your browser using DataLab