powered by
The function activates the capabilities of the nightly javascript library. The user can put it anywhere within the UI.
use_nightly()
called for the side effect of activating the scrollrevealjs library
# NOT RUN { # Put the function within your shiny ui use_nightly() # }
Run the code above in your browser using DataLab